# quantumsymmetry

Quantum computing research package

## Installation

```bash
$ pip install quantumsymmetry
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`quantumsymmetry` was created by Dario Picozzi. It is licensed under the terms of the GNU General Public License v3.0 license.

## Credits

`quantumsymmetry` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
